==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LocalityLoadBalancerSettingFailoverFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LocalityLoadBalancerSettingFailoverFluent<A extends LocalityLoadBalancerSettingFailoverFluent<A>> extends BaseFluent<A>{
  public LocalityLoadBalancerSettingFailoverFluent() {
  }
  public LocalityLoadBalancerSettingFailoverFluent(LocalityLoadBalancerSettingFailover instance) {
    instance = (instance != null ? instance : new LocalityLoadBalancerSettingFailover());

    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
  }
  private String from;
  private String to;
  public String getFrom() {
    return this.from;
  }
  public A withFrom(String from) {
    this.from=from; return (A) this;
  }
  public boolean hasFrom() {
    return this.from != null;
  }
  public String getTo() {
    return this.to;
  }
  public A withTo(String to) {
    this.to=to; return (A) this;
  }
  public boolean hasTo() {
    return this.to != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LocalityLoadBalancerSettingFailoverFluent that = (LocalityLoadBalancerSettingFailoverFluent) o;
    if (!java.util.Objects.equals(from, that.from)) return false;

    if (!java.util.Objects.equals(to, that.to)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  to,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (from != null) { sb.append("from:"); sb.append(from + ","); }
    if (to != null) { sb.append("to:"); sb.append(to); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LocalityLoadBalancerSettingFailoverFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LocalityLoadBalancerSettingFailoverFluent<A extends LocalityLoadBalancerSettingFailoverFluent<A>> extends BaseFluent<A>{
  public LocalityLoadBalancerSettingFailoverFluent() {
  }
  
  public LocalityLoadBalancerSettingFailoverFluent(LocalityLoadBalancerSettingFailover instance) {
    this.copyInstance(instance);
  }
  private String from;
  private String to;
  
  protected void copyInstance(LocalityLoadBalancerSettingFailover instance) {
    instance = (instance != null ? instance : new LocalityLoadBalancerSettingFailover());
  
    if (instance != null) {
        this.withFrom(instance.getFrom());
        this.withTo(instance.getTo());
        this.withFrom(instance.getFrom());
        this.withTo(instance.getTo());
      }
  }
  
  public String getFrom() {
    return this.from;
  }
  
  public A withFrom(String from) {
    this.from=from; return (A) this;
  }
  
  public boolean hasFrom() {
    return this.from != null;
  }
  
  public String getTo() {
    return this.to;
  }
  
  public A withTo(String to) {
    this.to=to; return (A) this;
  }
  
  public boolean hasTo() {
    return this.to != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LocalityLoadBalancerSettingFailoverFluent that = (LocalityLoadBalancerSettingFailoverFluent) o;
    if (!java.util.Objects.equals(from, that.from)) return false;
  
    if (!java.util.Objects.equals(to, that.to)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(from,  to,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (from != null) { sb.append("from:"); sb.append(from + ","); }
    if (to != null) { sb.append("to:"); sb.append(to); }
    sb.append("}");
    return sb.toString();
  }
  

}
